From 87958234e9e7c94709da7b4fe7ef2a588c08e422 Mon Sep 17 00:00:00 2001
From: Aaron Cannon <cannona@fireantproductions.com>
Date: Sun, 10 May 2015 15:38:02 -0500
Subject: [PATCH] Added option to start Speech Viewer on startup.

---
 source/config/__init__.py     | 1 +
 source/core.py                | 4 ++++
 source/gui/settingsDialogs.py | 5 +++++
 3 files changed, 10 insertions(+)

diff --git a/source/config/__init__.py b/source/config/__init__.py
index 1f28f8b..0ede066 100644
--- a/source/config/__init__.py
+++ b/source/config/__init__.py
@@ -63,6 +63,7 @@ confspec = ConfigObj(StringIO(
 	#possible log levels are DEBUG, IO, DEBUGWARNING, INFO
 	loggingLevel = string(default="INFO")
 	showWelcomeDialogAtStartup = boolean(default=true)
+	autoStartSpeechViewer = boolean(default=false)
 
 # Speech settings
 [speech]
diff --git a/source/core.py b/source/core.py
index c74f5b4..95f7243 100644
--- a/source/core.py
+++ b/source/core.py
@@ -59,6 +59,10 @@ def doStartupDialogs():
 		gui.messageBox(_("Your gesture map file contains errors.\n"
 				"More details about the errors can be found in the log file."),
 			_("gesture map File Error"), wx.OK|wx.ICON_EXCLAMATION)
+	if not globalVars.appArgs.minimal and config.conf["general"]["autoStartSpeechViewer"]:
+		log.debug("Automatically launching speech viewer")
+		gui.speechViewer.activate()
+		gui.mainFrame.sysTrayIcon.menu_tools_toggleSpeechViewer.Check(True)
 
 def restart(disableAddons=False):
 	"""Restarts NVDA by starting a new copy with -r."""
diff --git a/source/gui/settingsDialogs.py b/source/gui/settingsDialogs.py
index 30fa917..9651704 100644
--- a/source/gui/settingsDialogs.py
+++ b/source/gui/settingsDialogs.py
@@ -189,6 +189,10 @@ class GeneralSettingsDialog(SettingsDialog):
 		if globalVars.appArgs.secure or not config.isServiceInstalled():
 			self.startOnLogonScreenCheckBox.Disable()
 		settingsSizer.Add(self.startOnLogonScreenCheckBox)
+		# Translators: The label for a setting in general settings to cause NVDA to automatically start the Speech Viewer after NVDA is started. (This only starts after the user is logged in, not on the logon screen.)
+		self.autoStartSpeechViewerCheckBox = wx.CheckBox(self, wx.ID_ANY, label=_("Automatically start Speech &Viewer after NVDA starts"))
+		self.autoStartSpeechViewerCheckBox.SetValue(config.conf["general"]["autoStartSpeechViewer"])
+		settingsSizer.Add(self.autoStartSpeechViewerCheckBox)
 		# Translators: The label for a button in general settings to copy current user settings to system settings (to allow current settings to be used in secure screens such as User Account Control (UAC) dialog).
 		self.copySettingsButton= wx.Button(self, wx.ID_ANY, label=_("Use currently saved settings on the logon and other secure screens (requires administrator privileges)"))
 		self.copySettingsButton.Bind(wx.EVT_BUTTON,self.onCopySettings)
@@ -263,6 +267,7 @@ class GeneralSettingsDialog(SettingsDialog):
 		config.conf["general"]["saveConfigurationOnExit"]=self.saveOnExitCheckBox.IsChecked()
 		config.conf["general"]["askToExit"]=self.askToExitCheckBox.IsChecked()
 		config.conf["general"]["playStartAndExitSounds"]=self.playStartAndExitSoundsCheckBox.IsChecked()
+		config.conf["general"]["autoStartSpeechViewer"]=self.autoStartSpeechViewerCheckBox.IsChecked()
 		logLevel=self.LOG_LEVELS[self.logLevelList.GetSelection()][0]
 		config.conf["general"]["loggingLevel"]=logHandler.levelNames[logLevel]
 		logHandler.setLogLevelFromConfig()
-- 
1.9.4.msysgit.1

